==> mls-0.1.tar.gz: mls-0.1/lib/TargzUtil.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Byoungyoung, La                                 *
 *   la9527@yahoo.co.kr                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/ 
#ifndef TargzUtil_h_
#define TargzUtil_h_
 
#include "define.h"
#include "file.h"
#include "exception.h"

namespace MLS
{
	class TargzUtil
	{
		private:	
			string  		m_Filename;
			string			m_Dir;
			string			m_sCwd;
			
			string			m_GzipDir;
			string			m_Bzip2Dir;
			string			m_TarDir;
			
			bool			m_isZip;
			vector<File*>	m_tFileList;
			vector<string>	m_ErrorInfo;
			int				m_isFileInfo;
			
		protected:
			int		GetFileInfo(void);
			int		Chdir(void);
			int		BeforeChdir(void);
			
			string	GetTarFileName(void);
			
			bool	IsFileCreate(const string& sFilename = "");
			
			int		FileControl(const string& sFullName, int nAppendDel);
			
		public:
			TargzUtil(const string& sDir_Filename, bool isZip);
			TargzUtil(const string& sDir, const string& sFilename, bool isZip);
			~TargzUtil();
			
			uint 	GetCount(void) 	{ 	return (uint)m_tFileList.size(); }
			
			// Tar, gzip 등 디렉토리 위치 선정. 
			void	SetTarDir(string& GzipDir, string& Bzip2Dir, string& TarDir) 
			{
				m_GzipDir 	= GzipDir; m_Bzip2Dir	= Bzip2Dir;	m_TarDir 	= TarDir;
			}
			
			int		FileExtCheck(const char* sExt);
			int		CommandExecute(const string& sCommand);
			
			int		GetDir_Files(string& s_Dir, vector<MLS::File*>* pRe_Dir);
			int		GetDir_AllFiles(string& s_Dir, vector<MLS::File*>* pRe_Dir);
			int		GetAll_Files(vector<MLS::File*>* rRe_File);
	
			uint	GetAllDataSize(void);
			
			int		Compress(vector<MLS::File*>& t_FileList, int nAppendDel = TAR_APPEND);
			int		Compress(vector<string>& t_FileList, int nAppendDel = TAR_APPEND);
			int		Compress(MLS::File* pFile, int nAppendDel = TAR_APPEND);
			int		Compress(const string& s_Dir = "");
			
			int		Uncompress(vector<MLS::File*>& t_FileList, const string& sTargetDir = "");
			int		Uncompress(vector<string>& t_FileList, const string& sTargetDir = "");
			int		Uncompress(const string& s_Dir = "");
			
			int		FileListRead(void);
			
			int 	GetErrorList(vector<string>& tErrorList) { tErrorList = m_ErrorInfo; }
	};
}

#endif

==> mls-0.2.tar.gz: mls-0.2/lib/TargzUtil.h <==
/* *************************************************************************
 *   Copyright (C) 2004 by Byoungyoung, La                                 *
 *   la9527@yahoo.co.kr                                                    *
 *                                                                         *
 ************************************************************************* */ 

///	\file	TargzUtil.h
///	\brief	TargzUtil.h
#ifndef TargzUtil_h_
#define TargzUtil_h_
 
#include "define.h"
#include "file.h"
#include "exception.h"

namespace MLS
{
	///	\brief	zip, tar.gz 파일 관리 class
	class TargzUtil
	{
		private:
			map<string, int>	m_tReadCol;
			string  		m_Filename;		///< zip filename
			string			m_Dir;			///< zip file path
			string			m_sCwd;			///< 현 작업 공간 directory
			
			string			m_GzipDir;		///< GZipDir ?
			string			m_Bzip2Dir;		///< BZip2Dir ?
			string			m_TarDir;		///< TarDir ?
			
			bool			m_isZip;		///< Zip 파일 여부
			vector<File*>	m_tFileList;	///< 압축 파일에 있는 filelist
			vector<string>	m_ErrorInfo;	///< error info
			int				m_isFileInfo;	///< 압축 file 정보(tar.gz, tar...)
			
		protected:
			int		GetFileInfo(void);
			int		Chdir(void);
			int		BeforeChdir(void);
			
			string	GetTarFileName(void);
			
			bool	IsFileCreate(const string& sFilename = "");
			
			int		FileControl(const string& sFullName, int nAppendDel);
			int		Fullname_To_Filename(string* sFullFile, string* sFilename, bool* bDir);
			int		LineFormatRead(vector<string>&	vLineToken, File* pFileInfo, int nFormat);
			
			int		FileListCheck_DirInsert(void);
			
		public:
			TargzUtil(const string& sDir_Filename, bool isZip);
			TargzUtil(const string& sDir, const string& sFilename, bool isZip);
			~TargzUtil();
			
			///	\brief	파일 개수 반환 함수
			///	\return	파일 개수
			uint 	GetCount(void) 	{ 	return (uint)m_tFileList.size(); }
			
			///	\brief	Tar, gzip 등 디렉토리 위치 선정. 
			///	\param	GzipDir		??
			///	\param	Bzip2Dir	??
			///	\param	TarDir		??
			void	SetTarDir(string& GzipDir, string& Bzip2Dir, string& TarDir) 
			{
				m_GzipDir 	= GzipDir; m_Bzip2Dir	= Bzip2Dir;	m_TarDir 	= TarDir; 
			}
			
			int		FileExtCheck(const char* sExt);
			int		CommandExecute(const string& sCommand);
			
			int		GetDir_Files(string& s_Dir, vector<MLS::File*>* pRe_Dir);
			int		GetDir_AllFiles(string& s_Dir, vector<MLS::File*>* pRe_Dir);
			int		GetAll_Files(vector<MLS::File*>* rRe_File);
	
			uint	GetAllDataSize(void);
			
			int		Compress(vector<MLS::File*>& t_FileList, int nAppendDel = TAR_APPEND);
			int		Compress(vector<string>& t_FileList, int nAppendDel = TAR_APPEND);
			int		Compress(MLS::File* pFile, int nAppendDel = TAR_APPEND);
			int		Compress(const string& s_Dir = "");
			
			int		Uncompress(vector<MLS::File*>& t_FileList, const string& sTargetDir = "");
			int		Uncompress(vector<string>& t_FileList, const string& sTargetDir = "");
			int		Uncompress(const string& s_Dir = "");
			
			int		FileListRead(void);
			
			int 	GetErrorList(vector<string>& tErrorList) { tErrorList = m_ErrorInfo; }
	};
	
};

#endif
